@@ -440,13 +440,13 @@ class RetinaFace:
 
                 self.model.forward(db, is_train=False)
 
-                net_out_0 = self.model.get_outputs()
+                net_out = self.model.get_outputs()
                 # nd.waitall()
 
-                ctx = mx.cpu()
-                net_out = []
-                for i in range(len(net_out_0)):
-                    net_out.append(net_out_0[i].as_in_context(ctx))
+                # ctx = mx.cpu()
+                # net_out = []
+                # for i in range(len(net_out_0)):
+                #     net_out.append(net_out_0[i].as_in_context(ctx))
 
                 cnt = 0
                 for _idx, s in enumerate(self._feat_stride_fpn):
